@@ -64,11 +64,11 @@ class TestTutorialData(unittest.TestCase):
             self.assertEqual(len(data[0]), 1, "Expected one inputs")
             self.assertEqual(len(data[1]), 1, "Expected one outputs")
             self.assertEqual(len(data[2]), 1, "Expected one meta")
-            self.assertTrue('img' in data[0])
-            self.assertTrue('gt' in data[1])
-            self.assertTrue('meta' in data[2])
-            self.assertTupleEqual(data[0]['img'].shape, (1, 28, 28))
-            self.assertTupleEqual(data[1]['gt'].shape, (1, 1))
+            self.assertTrue("img" in data[0])
+            self.assertTrue("gt" in data[1])
+            self.assertTrue("meta" in data[2])
+            self.assertTupleEqual(data[0]["img"].shape, (1, 28, 28))
+            self.assertTupleEqual(data[1]["gt"].shape, (1, 1))
 
         check(train_data)
         check(val_data)
@@ -93,5 +93,5 @@ class TestTutorialTrain(unittest.TestCase):
         warmstart_training_test_case(self, self.scenario)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
