@@ -34,13 +34,13 @@ from tfaip.util.versioning import get_commit_hash
 if TYPE_CHECKING:
     from tfaip.scenario.scenariobase import ScenarioBase
 
-TDataParams = TypeVar('TDataParams', bound=DataBaseParams)
-TModelParams = TypeVar('TModelParams', bound=ModelBaseParams)
+TDataParams = TypeVar("TDataParams", bound=DataBaseParams)
+TModelParams = TypeVar("TModelParams", bound=ModelBaseParams)
 
 
 class ScenarioBaseParamsMeta(ReplaceDefaultDataClassFieldsMeta):
     def __new__(mcs, *args, **kwargs):
-        return super().__new__(mcs, *args, field_names=['data', 'model'], **kwargs)
+        return super().__new__(mcs, *args, field_names=["data", "model"], **kwargs)
 
 
 @pai_dataclass
@@ -52,6 +52,7 @@ class ScenarioBaseParams(Generic[TDataParams, TModelParams], ABC, metaclass=Scen
 
     NOTE: add @pai_dataclass and @dataclass annotations to inherited class
     """
+
     @classmethod
     def data_cls(cls) -> Type[TDataParams]:
         """Returns the class of the data params"""
@@ -62,46 +63,49 @@ class ScenarioBaseParams(Generic[TDataParams, TModelParams], ABC, metaclass=Scen
         """Returns the class of the model params"""
         return cls.__generic_types__[TModelParams.__name__]
 
-    debug_graph_n_examples: int = field(default=1, metadata=pai_meta(
-        help='number of examples to take from the validation set for debugging, -1 = all'
-    ))
+    debug_graph_n_examples: int = field(
+        default=1, metadata=pai_meta(help="number of examples to take from the validation set for debugging, -1 = all")
+    )
 
-    print_eval_limit: int = field(default=10, metadata=pai_meta(
-        help='Number of evaluation examples to print per evaluation, use -1 to print all'
-    ))
+    print_eval_limit: int = field(
+        default=10, metadata=pai_meta(help="Number of evaluation examples to print per evaluation, use -1 to print all")
+    )
 
-    tensorboard_logger_history_size: int = field(default=5, metadata=pai_meta(
-        help='Number of instances to store for outputing into tensorboard. Default (last n=5)'
-    ))
+    tensorboard_logger_history_size: int = field(
+        default=5,
+        metadata=pai_meta(help="Number of instances to store for outputing into tensorboard. Default (last n=5)"),
+    )
 
-    export_serve: bool = field(default=True, metadata=pai_meta(
-        help='Export the serving model (saved model format)'
-    ))
+    export_serve: bool = field(default=True, metadata=pai_meta(help="Export the serving model (saved model format)"))
 
-    model: TModelParams = field(default_factory=ModelBaseParams, metadata=pai_meta(
-        mode='flat',
-    ))
-    data: TDataParams = field(default_factory=DataBaseParams, metadata=pai_meta(
-        mode='flat',
-    ))
-    evaluator: EvaluatorParams = field(default_factory=EvaluatorParams, metadata=pai_meta(
-        mode='flat'
-    ))
+    model: TModelParams = field(
+        default_factory=ModelBaseParams,
+        metadata=pai_meta(
+            mode="flat",
+        ),
+    )
+    data: TDataParams = field(
+        default_factory=DataBaseParams,
+        metadata=pai_meta(
+            mode="flat",
+        ),
+    )
+    evaluator: EvaluatorParams = field(default_factory=EvaluatorParams, metadata=pai_meta(mode="flat"))
 
     # Additional export params
-    export_net_config: bool = field(default=True, metadata=pai_meta(mode='ignore'))
-    net_config_filename: str = field(default='net_config.json', metadata=pai_meta(mode='ignore'))
-    default_serve_dir: str = field(default='serve', metadata=pai_meta(mode='ignore'))
-    additional_serve_dir: str = field(default='additional', metadata=pai_meta(mode='ignore'))
-    trainer_params_filename: str = field(default='trainer_params.json', metadata=pai_meta(mode='ignore'))
-    scenario_params_filename: str = field(default='scenario_params.json', metadata=pai_meta(mode='ignore'))
+    export_net_config: bool = field(default=True, metadata=pai_meta(mode="ignore"))
+    net_config_filename: str = field(default="net_config.json", metadata=pai_meta(mode="ignore"))
+    default_serve_dir: str = field(default="serve", metadata=pai_meta(mode="ignore"))
+    additional_serve_dir: str = field(default="additional", metadata=pai_meta(mode="ignore"))
+    trainer_params_filename: str = field(default="trainer_params.json", metadata=pai_meta(mode="ignore"))
+    scenario_params_filename: str = field(default="scenario_params.json", metadata=pai_meta(mode="ignore"))
 
-    scenario_base_path: Optional[str] = field(default=None, metadata=pai_meta(mode='ignore'))
-    scenario_id: Optional[str] = field(default=None, metadata=pai_meta(mode='ignore'))
-    id: Optional[str] = field(default=None, metadata=pai_meta(mode='ignore'))
+    scenario_base_path: Optional[str] = field(default=None, metadata=pai_meta(mode="ignore"))
+    scenario_id: Optional[str] = field(default=None, metadata=pai_meta(mode="ignore"))
+    id: Optional[str] = field(default=None, metadata=pai_meta(mode="ignore"))
 
-    tfaip_commit_hash: str = field(default_factory=get_commit_hash, metadata=pai_meta(mode='ignore'))
-    tfaip_version: str = field(default=__version__, metadata=pai_meta(mode='ignore'))
+    tfaip_commit_hash: str = field(default_factory=get_commit_hash, metadata=pai_meta(mode="ignore"))
+    tfaip_version: str = field(default=__version__, metadata=pai_meta(mode="ignore"))
 
     def __post_init__(self) -> NoReturn:
         """
@@ -111,18 +115,19 @@ class ScenarioBaseParams(Generic[TDataParams, TModelParams], ABC, metaclass=Scen
         """
         pass
 
-    def cls(self) -> Type['ScenarioBase']:
+    def cls(self) -> Type["ScenarioBase"]:
         if self.scenario_id is None:
-            raise ValueError("Scenario param 'scenario_id' not set. Cannot determine scenario type automatically. "
-                             "Please override cls() in the scenario params or set 'scenario_id'.")
-        module, cls = self.scenario_id.split(':')
+            raise ValueError(
+                "Scenario param 'scenario_id' not set. Cannot determine scenario type automatically. "
+                "Please override cls() in the scenario params or set 'scenario_id'."
+            )
+        module, cls = self.scenario_id.split(":")
         return getattr(importlib.import_module(module), cls)
 
-    def create(self) -> 'ScenarioBase':
+    def create(self) -> "ScenarioBase":
         return self.cls()(self)
 
 
-
 @dataclass
 class NetConfigNodeSpec:
     shape: List[str]
